@@ -1,7 +1,7 @@
 # -*- encoding: utf-8 -*-
 __author__ = "Chmouel Boudjnah <chmouel@chmouel.com>"
-VERSION = "0.5.1"
-USER_AGENT = 'python-cloudb/%s' % VERSION
+VERSION = "0.6.1"
+USER_AGENT = 'python-cloudlb/%s' % VERSION
 
 # Default AUTH SERVER
 DEFAULT_AUTH_SERVER = "https://auth.api.rackspacecloud.com/v1.1/auth"
@@ -17,6 +17,10 @@ REGION = {
     "chicago": "ord",
     "dallas": "dfw",
     "london": "lon",
+    "sydney": "syd",
+    "ashburn": "iad",
+    "hongkong": "hkg",
+    "staging": "staging",
 }
 
 # Allowed Protocol
@@ -25,7 +29,9 @@ LB_PROTOCOLS = ["FTP", "HTTP", "IMAPv4", "POP3", "LDAP",
                 "POP3S", "SMTP", "TCP"]
 
 # Attributed allowed to be modified on loadbalancers
-LB_ATTRIBUTES_MODIFIABLE = ["name", "algorithm", "protocol", "port"]
+LB_ATTRIBUTES_MODIFIABLE = ["name", "algorithm", "protocol",
+                            "port", "timeout", "httpsRedirect",
+                            "halfClosed"]
 
 # Types of VirtualIPS
 VIRTUALIP_TYPES = ["PUBLIC", "SERVICENET"]
