@@ -1,5 +1,5 @@
 # -*- encoding: utf-8 -*-
-__author__ = "Chmouel Boudjnah <chmouel@chmouel.com>"
+__author__ = "Chmouel Boudjnah <chmouel@chmouel.com>, Randall Burt <randall.burt@rackspace.com>"
 from cloudlb import base
 from cloudlb.consts import LB_PROTOCOLS, LB_ATTRIBUTES_MODIFIABLE
 from cloudlb.errors import InvalidProtocol, InvalidLoadBalancerName
@@ -15,6 +15,7 @@ from cloudlb.connectionthrottle import ConnectionThrottleManager
 from cloudlb.errorpage import ErrorPage
 from cloudlb.ssltermination import SSLTermination
 
+
 class LoadBalancer(base.Resource):
     accessList = None
     sessionPersistence = None
@@ -135,16 +136,22 @@ class LoadBalancerManager(base.ManagerWithFind):
         return [x for x in \
                     self._list("/loadbalancers.json?nodeaddress=%s" % ip, 
                         "loadBalancers")]
-        
 
     def create(self, name, port,
-               protocol, nodes, virtualIps, algorithm='RANDOM'):
+               protocol, nodes, virtualIps, algorithm='RANDOM', timeout=30, **kwargs):
         """
         Create a new loadbalancer.
 
-        #TODO: Args
+        :param name: Name of the LB to create
+        :param port: Port number for the service you are load balancing
+        :param protocol: Protocol of the service which is being load balanced
+        :param nodes: List of nodes to be added to the LB
+        :param virtualIps: Type of vIP to add with creation of LB
+        :param algorithm: Algorithm that defines how traffic should be directed
+        :param timeout: Timeout (seconds) for unresponsive backend nodes
+        :param kwargs: Name-based arguments for optional LB parameters (such as metadata)
+        :rtype: :class:'LoadBalancer'
         """
-
         if not protocol in LB_PROTOCOLS:
             raise InvalidProtocol("''%s'' is not a valid protocol" % \
                                       (protocol))
@@ -154,7 +161,6 @@ class LoadBalancerManager(base.ManagerWithFind):
 
         if len(name) > 128:
             raise InvalidLoadBalancerName("LB name is too long.")
-
         body = {"loadBalancer": {
             "name": name,
             "port": base.getid(port),
@@ -162,7 +168,12 @@ class LoadBalancerManager(base.ManagerWithFind):
             "nodes": nodeDico,
             "virtualIps": vipDico,
             "algorithm": algorithm,
-            }}
+            "timeout": timeout
+        }}
+
+        if kwargs:
+            for key in kwargs:
+                body["loadBalancer"][key] = kwargs[key]
 
         return self._create("/loadbalancers", body, "loadBalancer")
 
@@ -197,7 +208,7 @@ class LoadBalancerManager(base.ManagerWithFind):
     def update(self, lb, originalInfo, info):
         ret = {}
         for k in LB_ATTRIBUTES_MODIFIABLE:
-            if k in originalInfo and info[k] != originalInfo[k]:
+            if k in info and info[k] != originalInfo.get(k):
                 ret[k] = info[k]
 
         if 'protocol' in ret.keys() and ret['protocol'] not in LB_PROTOCOLS:
@@ -210,3 +221,9 @@ class LoadBalancerManager(base.ManagerWithFind):
 
         self.api.client.put('/loadbalancers/%s' % base.getid(lb), body=ret)
 
+    def get_absolute_limits(self):
+        _, body = self.api.client.get("/loadbalancers/absolutelimits")
+        return {name: val for name, val in [(item.get('name'),
+                                             item.get('value'))
+                                            for item in
+                                            body.get('absolute')]}
